from setuphelpers import *
import subprocess
import os

app_name = "Supermium"
app_dir = makepath(programfiles, app_name)
supermium_exe = makepath(app_dir, "chrome.exe")
user_data_dir = '--user-data-dir="%APPDATA%/Supermium"'
audit_version = False

def install():
    print("Starting installation of Supermium")
    # Kill impacted processes
    killalltasks(ensure_list(control.impacted_process))
    
    if isfile(supermium_exe):
        if force or Version(get_version_from_binary(supermium_exe)) < Version(control.get_software_version()):
            remove_tree(app_dir)

    if not isdir(app_dir):
        copytree2(app_name, app_dir)
    
    # Create shortcuts
    print("Creating desktop shortcut")
    create_desktop_shortcut("Supermium", target=supermium_exe, arguments=user_data_dir)
    print("Creating programs menu shortcut")
    create_programs_menu_shortcut("Supermium", target=supermium_exe, arguments=user_data_dir)
    print("Installation completed")

def audit():
    # Auditing software
    audit_status = "OK"
    installed_version = get_version_from_binary(supermium_exe)
    if Version(installed_version) < Version(control.get_software_version()) and audit_version:
        print("%s is installed in version (%s) instead of (%s)" % (app_name, installed_version, control.get_software_version()))
        audit_status = "WARNING"
    elif isdir(app_dir) and not dir_is_empty(app_dir):
        print("%s (%s) is installed" % (app_name, installed_version))
        audit_status = "OK"
    else:
        print("%s is not installed" % app_name)
        audit_status = "ERROR"
    return audit_status

def uninstall():
    print("Starting uninstallation of Supermium")
    # Kill impacted processes
    killalltasks(ensure_list(control.impacted_process))
    
    # Remove installation directory
    if isdir(app_dir):
        print(f"Removing installation directory: {app_dir}")
        remove_tree(app_dir)

    # Removing shortcuts
    print("Removing desktop shortcut")
    remove_desktop_shortcut(app_name)
    print("Removing programs menu shortcut")
    remove_programs_menu_shortcut(app_name)
    print("Uninstallation completed")

